#ifndef GAME_H
#define GAME_H

#include <qobject.h>
#include <qlist.h>

#include "card.h"

class WelcomeWindow;
class MainWindow;
class Suit;
class Player;
class Game;
class Deck;

// Global variable to hold current game info
extern Game* game;

class Game : public QObject
{
	Q_OBJECT

public:
	Game( WelcomeWindow* welcomeWindow );
	virtual ~Game() {}

	MainWindow* getMainWindow() { return mainWindow; }
	Player* getPlayer( int playerIndex ) { return players[playerIndex]; }
	int getCurrentPlayer() { return currentPlayer; }
	int getFirstPlayer() { return firstPlayer; }
	Card* getTrickCard( int playerIndex ) { return trick[playerIndex]; }
	bool getSpadesPlayed() { return spadesPlayed; }

	Suit* getLeadSuit();
	void cardPlayed(Card* card);
	bool cardHasBeenPlayed(Suit* suit, int value);
	int calculateWinner();
	void deal();
	void recordBid();
	void showHand( Player* player );
	void hideHand();
	void showMessage( QString message );
	void hideMessage();
	void nextPlayer();
	void nextDealer();
	bool isValidCardToPlay(int cardIndex);
	Card* getHighestTrickCard();
	int getMinimumBid();
	Player* getPartner( Player* player );
	Player* getPlayerOnLeft( Player* player );
	Player* getPlayerOnRight( Player* player );
	Card* getTrickCard( Player* player );

private:
	void setPlayers();
	void startNewHand();
	void playCard();
	int calculateScore( Player* playerA, Player* playerB );
	int calculateBidScore( int bid, int tricks );
	int calculateUnderbid( Player* playerA, Player* playerB );
	void updateTeamTotals();
	void handFinished();
	void gameFinished();
	QString getBidString(int playerIndex);
	int getPlayerIndex( Player *player );

	MainWindow* mainWindow;
	WelcomeWindow* welcomeWindow;
	int currentPlayer;
	int firstPlayer;
	int dealer;
	Card* trick[4];
	QList<Card> playedCards;
	bool firstTrick;
	bool spadesPlayed;
	int lastWinner;
	Player* players[4];
	Deck* deck;
	int team1Score;
	int team2Score;
	int team1Underbid;
	int team2Underbid;

public slots:
	void newGame();
	void playTrick();
	void waitForUserToAcknowledgeWinner();
	void trickFinished();
};

#endif // GAME_H
