#include "handview.h"
#include "card.h"
#include "suit.h"
#include "player.h"

#include <qpainter.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qpushbutton.h>

//##############################################################################
HandView::HandView( QWidget *parent, const char *name ) : QWidget( parent, name ) 
{
	player = NULL;
	layout = NULL;
	label = NULL;
	button = NULL;
}

//##############################################################################
void HandView::showHand( Player* player ) 
{
	this->player = player;
	update();
}

//##############################################################################
void HandView::hideHand() 
{
	this->player = NULL;
	disconnect(); // Disconnect all signals from hand window
	update();
}

//##############################################################################
/**
 * Displays a message in the hand area and waits for user to click Ok button
 */
void HandView::showMessage( QString message ) 
{
	//qDebug("HandView::showMessage("+message+") start");
	// If label and button haven't been created yet, create them
	if (layout==NULL) {
		layout = new QVBoxLayout( this ); 
		layout->setSpacing( 4 );
		layout->setMargin( 2 );
		label = new QLabel( message, this );
		label->setBackgroundColor( QColor( 0, 170, 0 ) );
		label->setFont( QFont( "Courier", 16, QFont::Bold ) );
		label->setAlignment( int( QLabel::AlignCenter ) );
		layout->addWidget( label );
		button = new QPushButton( "&Ok", this );
		button->setMaximumSize( QSize( 50, 32 ) ); 
		layout->addWidget( button );
	}

	// Show the label and button
	label->setText( message );
	label->show();
	button->show();
	update();
	//qDebug("HandView::showMessage("+message+") end");
}

//##############################################################################
void HandView::hideMessage() 
{
	//qDebug("HandView::clearMessage() start");
	button->disconnect(); // Disconnect all signals from message button
	label->hide();
	button->hide();
	update();
	//qDebug("HandView::clearMessage() end");
}

//##############################################################################
int HandView::calculateCardOffset() 
{
	return (rect().width()-(8+Card::width)) / 12;
}

//##############################################################################
void HandView::paintEvent( QPaintEvent* e ) 
{
	Q_UNUSED(e);
	//qDebug("HandView::paintEvent start");
	QPainter p( this );
	p.setPen( black );
	p.drawLine( 0, 0, rect().right(), 0 );

	if (player != NULL) {
		// Draw cards
		int offset = calculateCardOffset();
		int cardCount = player->getCardCount();
		for (int i=0; i<cardCount; i++) {
			Card* card = player->getCard(i);
			card->draw( &p, 4+(i*offset), 4 );
		}
	}
	//qDebug("HandView::paintEvent end");
}

//##############################################################################
void HandView::mousePressEvent( QMouseEvent *e )
{
	if ( e->button() != LeftButton )
		return;
	if ( player!=NULL ) {
		int offset = calculateCardOffset();
		int cardIndex = (e->x()-4) / offset;
		if (cardIndex>=0 && cardIndex<player->getCardCount())
			emit cardSelected( cardIndex );
		else if (cardIndex>=player->getCardCount()) {
			// See if user clicked on additional visible part of last card in hand
			int lastCardStartPos = 4 + (offset * (player->getCardCount()-1));
			int lastCardEndPos = lastCardStartPos + Card::width - 1;
			if (e->x()<=lastCardEndPos)
				emit cardSelected( player->getCardCount()-1 );
		}
	}
}


