#include "mainwindow.h"
#include "tableview.h"
#include "handview.h"
#include "card.h"
#include "game.h"

#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>

/* 
 *  Constructs a MainWindow which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f'.
 *
 */
MainWindow::MainWindow( QWidget* parent,  const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "MainWindow" );
    setCaption( tr( "Spades" ) );
    QVBoxLayout* mainLayout = new QVBoxLayout( this ); 
    mainLayout->setSpacing( 0 );
    mainLayout->setMargin( 4 );

    tableView = new TableView( this, "tableView" );
    tableView->setMinimumSize( QSize( 192, 180 ) );
    tableView->setBackgroundColor( QColor( 0, 170, 0 ) );
    mainLayout->addWidget( tableView );

    handView = new HandView( this, "handView" );
    handView->setMinimumSize( QSize( 0, Card::height+8 ) );
    handView->setMaximumSize( QSize( 240, Card::height+8 ) );
    handView->setBackgroundColor( QColor( 0, 170, 0 ) );
    mainLayout->addWidget( handView );

    QGridLayout* Layout1 = new QGridLayout( 0, 1, 1, 0, 2, "Layout1"); 

    int fontSize = 12;

    QLabel* label1 = new QLabel( tr( "Teams" ), this, "TextLabel17" );
    label1->setFont( QFont( "Courier", fontSize, QFont::Bold ) );
    Layout1->addWidget( label1, 0, 0 );

    QLabel* label5 = new QLabel( tr( "Tricks" ), this, "TextLabel5" );
    label5->setFont( QFont( "Courier", fontSize, QFont::Bold ) );
    label5->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( label5, 0, 1 );

    QLabel* label6 = new QLabel( tr( "Bid" ), this, "TextLabel6" );
    label6->setFont( QFont( "Courier", fontSize, QFont::Bold ) );
    label6->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( label6, 0, 2 );

    QLabel* label7 = new QLabel( tr( "Score" ), this, "TextLabel7" );
    label7->setFont( QFont( "Courier", fontSize, QFont::Bold ) );
    label7->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( label7, 0, 3 );

    QLabel* label8 = new QLabel( tr( "Over" ), this, "TextLabel8" );
    label8->setFont( QFont( "Courier", fontSize, QFont::Bold ) );
    label8->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( label8, 0, 4 );


    team1Names = new QLabel( tr( "Player1/Player3" ), this, "team1Label" );
    team1Names->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    Layout1->addWidget( team1Names, 1, 0 );

    team1Tricks = new QLabel( tr( "0/0" ), this, "team1Tricks" );
    team1Tricks->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team1Tricks->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team1Tricks, 1, 1 );

    team1Bid = new QLabel( tr( "0/0" ), this, "team1Bid" );
    team1Bid->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team1Bid->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team1Bid, 1, 2 );

    team1Score = new QLabel( tr( "0" ), this, "team1Score" );
    team1Score->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team1Score->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team1Score, 1, 3 );

    team1Underbid = new QLabel( tr( "0" ), this, "team1Underbid" );
    team1Underbid->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team1Underbid->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team1Underbid, 1, 4 );

    team2Names = new QLabel( tr( "Player2/Player4" ), this, "team2Label" );
    team2Names->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    Layout1->addWidget( team2Names, 2, 0 );

    team2Tricks = new QLabel( tr( "0/0" ), this, "team2Tricks" );
    team2Tricks->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team2Tricks->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team2Tricks, 2, 1 );

    team2Bid = new QLabel( tr( "0/0" ), this, "team2Bid" );
    team2Bid->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team2Bid->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team2Bid, 2, 2 );

    team2Score = new QLabel( tr( "0" ), this, "team2Score" );
    team2Score->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team2Score->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team2Score, 2, 3 );

    team2Underbid = new QLabel( tr( "0" ), this, "team2Overbid" );
    team2Underbid->setFont( QFont( "Courier", fontSize, QFont::Normal ) );
    team2Underbid->setAlignment( int( QLabel::AlignCenter ) );
    Layout1->addWidget( team2Underbid, 2, 4 );

    mainLayout->addLayout( Layout1 );
}

