#ifndef PLAYER_H
#define PLAYER_H

#include <qobject.h>
#include <qstring.h>
#include <qlist.h>
#include "card.h"

class Player : public QObject
{
	Q_OBJECT
public:
	Player( QString name, bool human );
	~Player() {}

	// Accessors / mutators
	QString getName() { return name; }
	void setName( QString name ) { this->name=name; }
	bool isHuman() { return human; }
	void setHuman( bool human ) { this->human=human; }
	int getTricks() { return tricks; }
	void setTricks( int tricks ) { this->tricks=tricks; }
	int getBid() { return bid; }
	void setBid( int bid ) { this->bid=bid; }

	void clearTotals();
	void addCard( Card* card );
	void throwAwayCards();
	int getCardCount();
	Card* getCard(int index);
	void waitForReadyToSelectCard();
	Card* calculateCard(bool isLeadPlayer);
	bool hasOnlySpades();
	bool hasSuit( Suit* suit );
	void requestBid();
	QString handToString();

public slots:
	void playSelectedCard( int cardIndex );
	void promptForBid();
	void waitForCardToBeSelected();

private:
	QString name;		// Player name
	bool human;		// True if human player, false if computer player
	QList<Card> cards;	// Player's cards
	int bid;		// Player's bid on current hand
	int tricks;		// Number of tricks this player has won during current hand

	void calculateBid();
	int haveCard(int value, bool includeSpades);
	Card* findHighCardInSuit();
	bool isHighCard( Card* card );
	Card* findHighestCard( bool includeSpades );
	Card* findLowestCard( bool includeSpades );
	Card* getHighestCardInSuit( Suit* suit );
	Card* getLowestCardInSuit( Suit* suit );
	Card* getLowestWinningSpade();
	int getShortSuitCount( Suit* suit );
	bool haveCard(int value, Suit* suit);
	int getTotalCardsInSuit( Suit* suit );
	bool misdealAllowed();
	bool shouldPlayNil();
	int canCoverHighCards( Suit* suit, int minimumLowCards );
	void warnOfNilBids();
	Card* getHighestLosingCardInSuit( Suit* suit, Card* highestTrickCard );
	Card* getLowestWinningCardInSuit( Suit* suit, Card* highestTrickCard );
	Card* calculateCardWithNoNil(bool isLeadPlayer, Card* partnerCard);
	Card* calculateCardWithMeNil(bool isLeadPlayer);
	Card* calculateCardWithPartnerNil(bool isLeadPlayer, Card* partnerCard);
	Card* calculateCardWithOpponentNil(bool isLeadPlayer);
};

#endif // PLAYER_H
